#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-lexer
version:              1.2
visibility:           public
id:                   haskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
key:                  haskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
license:              MIT
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  08d01eeb1be9309995eda1324e8dba16
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-lexer-1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-lexer-1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-lexer-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lexer
hs-libraries:         HShaskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

